@@ -1,6 +1,6 @@
 ;;; ellama-transient.el --- Transient menus for ellama -*- lexical-binding: t; package-lint-main-file: "ellama.el"; -*-
 
-;; Copyright (C) 2023-2025  Free Software Foundation, Inc.
+;; Copyright (C) 2023-2026  Free Software Foundation, Inc.
 
 ;; Author: Sergey Kostyaev <sskostyaev@gmail.com>
 ;; SPDX-License-Identifier: GPL-3.0-or-later
@@ -409,9 +409,10 @@ ARGS used for transient arguments."
     ("b" "Blueprint" ellama-blueprint-select)
     ("U" "User defined blueprint" ellama-blueprint-select-user-defined-blueprint)
     ("C" "Community blueprint" ellama-community-prompts-select-blueprint)]
-   ["Create"
+   ["Manage"
     ("c" "Create from buffer" ellama-blueprint-create)
-    ("n" "New blueprint" ellama-blueprint-new)]
+    ("n" "New blueprint" ellama-blueprint-new)
+    ("r" "Remove blueprint" ellama-blueprint-remove)]
    ["Quit" ("q" "Quit" transient-quit-one)]])
 
 ;;;###autoload (autoload 'ellama-transient-blueprint-mode-menu "ellama-transient" nil t)
